summaryrefslogtreecommitdiffstats
path: root/xmloff/source/text/XMLRedlineExport.hxx
diff options
context:
space:
mode:
authorDaniel Vogelheim <dvo@openoffice.org>2001-01-10 19:51:01 +0000
committerDaniel Vogelheim <dvo@openoffice.org>2001-01-10 19:51:01 +0000
commitdaa3875fdcd9e5f646416a6bfc8207558f788254 (patch)
treeb60263f5b3ea61af4fd8be3a72278c8d8eaff805 /xmloff/source/text/XMLRedlineExport.hxx
parentRuby dialog (diff)
downloadcore-daa3875fdcd9e5f646416a6bfc8207558f788254.tar.gz
core-daa3875fdcd9e5f646416a6bfc8207558f788254.zip
- continued: redline im-/export
(works only within paragraphs, thus still disabled in txtparae.cxx)
Diffstat (limited to 'xmloff/source/text/XMLRedlineExport.hxx')
-rw-r--r--xmloff/source/text/XMLRedlineExport.hxx18
1 files changed, 10 insertions, 8 deletions
diff --git a/xmloff/source/text/XMLRedlineExport.hxx b/xmloff/source/text/XMLRedlineExport.hxx
index 4d4e98ca8db0..686e4a61347c 100644
--- a/xmloff/source/text/XMLRedlineExport.hxx
+++ b/xmloff/source/text/XMLRedlineExport.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: XMLRedlineExport.hxx,v $
*
- * $Revision: 1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: dvo $ $Date: 2001-01-02 14:38:40 $
+ * last change: $Author: dvo $ $Date: 2001-01-10 20:51:01 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -77,6 +77,7 @@
class SvXMLExport;
namespace com { namespace sun { namespace star {
namespace beans { class XPropertySet; }
+ namespace beans { struct PropertyValue; }
} } }
namespace rtl {
class OUString;
@@ -114,8 +115,6 @@ class XMLRedlineExport
SvXMLExport& rExport;
ChangesListType aChangesList; /// list of changes
- sal_Int32 nCountCallsExportChangedRegion;
- sal_Int32 nCountCallsExportChangeInline;
public:
@@ -156,20 +155,23 @@ private:
const ::com::sun::star::uno::Reference<
::com::sun::star::beans::XPropertySet> & rPropSet);
/// export an change-info element
void ExportChangeInfo(
const ::com::sun::star::uno::Reference<
::com::sun::star::beans::XPropertySet> & rPropSet);
+ /// export an change-info element (from PropertyValues)
+ void ExportChangeInfo(
+ const ::com::sun::star::uno::Sequence<
+ ::com::sun::star::beans::PropertyValue> & rValues);
+
/// convert the change type from API to XML names
const ::rtl::OUString ConvertTypeName(const ::rtl::OUString& sApiName);
- // HACK: IDs need to be dealt with properly!!!
/// Get ID string!
const ::rtl::OUString GetRedlineID(
const ::com::sun::star::uno::Reference<
- ::com::sun::star::beans::XPropertySet> & rPropSet,
- sal_Bool bFirstPass, sal_Bool bIsStart);
+ ::com::sun::star::beans::XPropertySet> & rPropSet);
};
@@ -156,20 +155,23 @@ private:
const ::com::sun::star::uno::Reference<
::com::sun::star::beans::XPropertySet> & rPropSet);
- /// export an change-info element
+ /// export an change-info element (from a PropertySet)
void ExportChangeInfo(
const ::com::sun::star::uno::Reference<